export function dateFormat(date, options) {
    if (!date)
        return;
    return new Intl.DateTimeFormat('th-TH', options).format(date);
}
export function getDayOfWeek(dayNumber, options) {
    const date = new Date(1970, 0, 4 + dayNumber);
    return new Intl.DateTimeFormat('th-TH', options).format(date);
}
export function getPreviousMonth(date) {
    const newDate = new Date(date);
    newDate.setHours(0, 0, 0, 0);
    newDate.setMonth(newDate.getMonth() - 1);
    return newDate;
}
export function getNextMonth(date) {
    const d = new Date(date);
    d.setHours(0, 0, 0, 0);
    d.setDate(1);
    d.setMonth(d.getMonth() + 1);
    return d;
}
export function convertDateStringToDate(dateString) {
    if (!dateString)
        return undefined;
    const [year, month, date] = dateString.split('-').map(Number);
    return new Date(year, month, date);
}
export function convertToDate(year, month, date = 1) {
    return new Date(+year, +month, +date);
}
export function convertDateToArrayNumber(date) {
    if (!date)
        return;
    return [date.getFullYear(), date.getMonth(), date.getDate()];
}
export const dateShortOption = {
    dateStyle: 'short',
};
export const longMonthOption = {
    month: 'long',
};
export const shortDayOption = {
    weekday: 'short',
};
export const yearDayOption = {
    year: 'numeric',
};
const getCalendarType = (date, targetMonth) => date.getMonth() === targetMonth
    ? 'current-month'
    : date.getMonth() < targetMonth
        ? 'previous-month'
        : 'next-month';
const getPeriod = (today, date) => {
    const diff = today.getTime() - date.getTime();
    const daysAgo = Math.floor(diff / (1000 * 3600 * 24));
    if (daysAgo === 0) {
        return 'today';
    }
    else if (daysAgo > 0) {
        return daysAgo === 1 ? `1 day ago` : `${daysAgo} days ago`;
    }
    else {
        const nextDays = Math.abs(daysAgo);
        return nextDays === 1 ? `1 day later` : `in ${nextDays} days later`;
    }
};
const getMinMax = (configMin, configMax, date) => {
    if (configMin && date < configMin) {
        return 'min';
    }
    else if (configMax && date > configMax) {
        return 'max';
    }
    else {
        return undefined;
    }
};
export const getCalendarDetail = ({ date, today = new Date(), min, max, }) => {
    const firstDateOfMonth = new Date(date.getFullYear(), date.getMonth(), 1);
    const lastDateOfMonth = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    const calendar = [];
    const firstDayOfMonth = firstDateOfMonth.getDay();
    let currentDate = new Date(firstDateOfMonth.getFullYear(), firstDateOfMonth.getMonth(), -firstDayOfMonth + 1);
    let minDate;
    if (min) {
        minDate = new Date(min);
        minDate.setHours(0);
        minDate.setMinutes(0);
        minDate.setSeconds(0);
    }
    let maxDate;
    if (max) {
        maxDate = new Date(max);
        maxDate.setHours(0);
        maxDate.setMinutes(0);
        maxDate.setSeconds(0);
    }
    for (let weekRow = 0; weekRow < 6; weekRow++) {
        const week = [];
        for (let dayIndex = 0; dayIndex < 7; dayIndex++) {
            const value = currentDate.getDate();
            const type = getCalendarType(currentDate, date.getMonth());
            const period = getPeriod(today, currentDate);
            const minmax = getMinMax(minDate, maxDate, currentDate);
            week.push({
                value,
                type,
                period,
                dateArray: convertDateToArrayNumber(currentDate),
                minmax,
                date: new Date(currentDate),
            });
            currentDate.setDate(currentDate.getDate() + 1);
        }
        calendar.push(week);
    }
    return {
        year: firstDateOfMonth.getFullYear(),
        month: firstDateOfMonth.getMonth(),
        calendar,
        firstDateOfMonth,
        lastDateOfMonth,
    };
};
export const isValid = (date) => !isNaN(date.getDate());
export const isAfter = (date) => {
    return date.starter > date.comparator ? true : false;
};
export const isBefore = (date) => {
    return date.starter < date.comparator ? true : false;
};
export function getDateBetweenArrayDate(date1, date2) {
    let startDate = new Date(date1);
    let endDate = new Date(date2);
    if (startDate > endDate) {
        // Swap start and end dates
        [startDate, endDate] = [endDate, startDate];
    }
    const dateArray = [];
    const currentDate = new Date(startDate);
    while (currentDate <= endDate) {
        dateArray.push(new Date(currentDate));
        currentDate.setDate(currentDate.getDate() + 1);
    }
    return dateArray;
}
// 📌 result [[2023,1,15], [2023,1,15]]
export function getDateBetweenArrayNumber(date1, date2) {
    let startDate = new Date(date1);
    let endDate = new Date(date2);
    if (startDate > endDate) {
        // Swap start and end dates
        [startDate, endDate] = [endDate, startDate];
    }
    const dateArray = [];
    const currentDate = new Date(startDate);
    while (currentDate <= endDate) {
        dateArray.push(convertDateToArrayNumber(new Date(currentDate)));
        currentDate.setDate(currentDate.getDate() + 1);
    }
    return dateArray;
}
// 📌 result [{2023-1: 4}, {2023-1: 5}]
export function getDateBetweenObject(date1, date2) {
    let startDate = new Date(date1);
    let endDate = new Date(date2);
    if (startDate > endDate) {
        // Swap start and end dates
        [startDate, endDate] = [endDate, startDate];
    }
    const dateArray = [];
    const currentDate = new Date(startDate);
    while (currentDate <= endDate) {
        const [year, month, date] = convertDateToArrayNumber(new Date(currentDate));
        const key = `${year}-${month}`;
        dateArray.push({ [key]: date });
        currentDate.setDate(currentDate.getDate() + 1);
    }
    return dateArray;
}
// 📌 result [{2023-1: [4,5,6]}, {2023-1: [5,6,7]}]
export function getDateBetweenObjectArray(date1, date2) {
    let startDate = new Date(date1);
    let endDate = new Date(date2);
    if (startDate > endDate) {
        // Swap start and end dates
        [startDate, endDate] = [endDate, startDate];
    }
    const dateObject = {};
    const currentDate = new Date(startDate);
    currentDate.setDate(currentDate.getDate() + 1); // move to first date after startDate
    while (currentDate < endDate) {
        const [year, month, date] = convertDateToArrayNumber(new Date(currentDate));
        const key = `${year}-${month}`;
        if (key in dateObject) {
            dateObject[key].push(date);
        }
        else {
            dateObject[key] = [date];
        }
        currentDate.setDate(currentDate.getDate() + 1);
        if (currentDate.getTime() === endDate.getTime()) {
            break; // end on last date before endDate
        }
    }
    return dateObject;
}
export function isDateBetween(startDate, endDate, checkDate) {
    return ((checkDate >= startDate && checkDate <= endDate) ||
        (checkDate >= endDate && checkDate <= startDate));
}
export const generateYearGroup = (date, yearCount) => {
    const year = date.getFullYear();
    const result = [];
    for (let i = year - yearCount; i <= year; i++) {
        result.push(i);
    }
    return result;
};
//# sourceMappingURL=date-methods.js.map